## NAME
youtube-dlG - GUI for youtube-dl

## DESCRIPTION
A cross platform front-end GUI of the popular youtube-dl 
written in wxPython.

## SCREENSHOT
![Youtube-dl-gui main window](http://i.imgur.com/I4oXPWs.png)

![Options window](http://i.imgur.com/eShdoLD.png)

## INSTALLATION
**Linux**: sudo python setup.py install

Then you can call youtube-dlg from the command line
using "youtube-dl-gui" command or by creating a desktop launcher

**Windows**: Check WINDOWS_SETUP

## WINDOWS_SETUP
http://code.google.com/p/youtube-dlg/

## LINUX_PACKAGES
**Ubuntu**: http://ppa.launchpad.net/nilarimogard/webupd8/ubuntu/pool/main/y/youtube-dlg/

**Arch**: https://aur.archlinux.org/packages/youtube-dl-gui-git/

## ADD SUPPORT FOR NEW LANGUAGE
See https://github.com/MrS0m30n3/youtube-dl-gui/blob/master/locale_build/HOWTO.md

## REQUIREMENTS
[Python (version 2.7+)](http://www.python.org)

[wxPython](http://wxpython.org)

[FFMPEG & FFPROBE](http://www.ffmpeg.org)
**Optional (In order to conver video files to audio-only files)

## PROJECT HOMEPAGE

**Youtube-dlG**: http://mrs0m30n3.github.io/youtube-dl-gui/

**Youtube-dl**: http://rg3.github.io/youtube-dl/

## AUTHOR

Sotiris Papadopoulos

email:  <ytubedlg@gmail.com>

twitter: https://twitter.com/MrS0m30n3

## THANKS

Thanks to youtube-dl authors for creating such and amazing tool.
